# eric7.Testing.__init__

Package implementing testing functionality and interface to various test frameworks.

### Global Attributes

None

### Classes

None

### Functions

isLanguageSupported | Function to check, if the given programming language is supported by any testing framework.
supportedLanguages | Function to get a list of supported programming languages.

## isLanguageSupported

isLanguageSupported(language)

Function to check, if the given programming language is supported by any testing framework.

language (str)
  programming language

Return:
  flag indicating support

Return Type:
  bool

Up

## supportedLanguages

supportedLanguages()

Function to get a list of supported programming languages.

Return:
  list of supported programming languages

Return Type:
  list of str

Up